@@ -9,13 +9,20 @@ from langchain_community.tools.tavily_search import TavilySearchResults
 
 def main():
     """Main CLI entrypoint for genos"""
-    if not os.environ.get("GROQ_API_KEY"):
-        print("❌ Error: GROQ_API_KEY environment variable not set")
-        return
+    groq_api_key = os.environ.get("GROQ_API_KEY")
+    if not groq_api_key:
+        groq_api_key = input("Enter your GROQ API Key: ").strip()
+        if not groq_api_key:
+            print("❌ GROQ API Key is required. Exiting.")
+            return
 
-    if not os.environ.get("TAVILY_API_KEY"):
-        print("❌ Error: TAVILY_API_KEY environment variable not set")
-        return
+    # Get Tavily API key
+    tavily_api_key = os.environ.get("TAVILY_API_KEY")
+    if not tavily_api_key:
+        tavily_api_key = input("Enter your Tavily API Key: ").strip()
+        if not tavily_api_key:
+            print("❌ Tavily API Key is required. Exiting.")
+            return
 
     # Initialize LLM + tools
     llm = ChatGroq(
